@@ -7,7 +7,7 @@ package Mojo::DOM58::_CSS;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '1.000';
 
 my $ESCAPE_RE = qr/\\[^0-9a-fA-F]|\\[0-9a-fA-F]{1,6}/;
 my $ATTR_RE   = qr/
@@ -58,9 +58,9 @@ sub _attr {
 
   my $attrs = $current->[2];
   for my $name (keys %$attrs) {
-    next unless $name =~ $name_re;
-    return 1 unless defined $attrs->{$name} && defined $value_re;
-    return 1 if $attrs->{$name} =~ $value_re;
+    my $value = $attrs->{$name};
+    next if $name !~ $name_re || (!defined $value && defined $value_re);
+    return 1 if !(defined $value && defined $value_re) || $value =~ $value_re;
   }
 
   return undef;
